#!/bin/bash

######################### CONFIG OPTIONS ############################
BACKEND_USER="flys28"
BACKEND_PASS="flys28"
BACKEND_HOST="czech-republic.atlas.intevation.de"
BACKEND_PORT="1521"
BACKEND_NAME="XE"
LOG4J_CONFIG="conf/log4j.properties"
JAR="bin/river-backend-1.0-SNAPSHOT*.jar"
#####################################################################


########################## Oracle Settings ##########################
BACKEND_DB_PREFIX="jdbc:oracle:thin:@"
BACKEND_DB_DRIVER="oracle.jdbc.OracleDriver"
BACKEND_DB_DIALECT="org.hibernate.dialect.OracleDialect"
BACKEND_URL=$BACKEND_DB_PREFIX//$BACKEND_HOST:$BACKEND_PORT/$BACKEND_NAME
#####################################################################


######################## Custom Importer Settings ###################
IMPORTER_DRY_RUN=false
IMPORTER_ANNOTATION_TYPES="conf/annotation-types.xml"

#Alle Importtypen ueberspringen, fuer die kein Skip-Schalter angegeben wird
IMPORTER_SKIP_DEFAULT=true

#Schifffahrt/Selektierte_Zusaetzliche_Laengsschnitte
IMPORTER_SKIP_SINFO_SELECTED_ADDITIONAL=false

#Schifffahrt/Infrastrukturen_BWaStr
IMPORTER_SKIP_SINFO_INFRASTRUCTURE=false

#Schifffahrt/Basisdaten/: Einteilung_der_Gewaessersohle.csv
IMPORTER_SKIP_SINFO_BED_MOBILITY=false

#Schifffahrt/Zu_gewaehrleistende_Fahrrinnenverhaeltnisse
IMPORTER_SKIP_SINFO_CHANNEL=false

#Schifffahrt/Grundberuehrungen/Einzeljahre
IMPORTER_SKIP_SINFO_COLLISION=false

#Schifffahrt/Basisdaten/.._mittlerer_tagesabfluss.csv
IMPORTER_SKIP_SINFO_DAILY_DISCHARGE=false

#Schifffahrt/Transportkoerperhoehen/...
IMPORTER_SKIP_SINFO_TKH=false

#Schifffahrt/Modellierte_Datensaetze/Fliesstiefen
IMPORTER_SKIP_SINFO_FLOW_DEPTH=false

#Schifffahrt/Fliesstiefenentwicklung/...
IMPORTER_SKIP_SINFO_DEPTH_EVOLUTION=false

#Oekologie/Iota/Iota
IMPORTER_SKIP_UINFO_IOTA=false

#Oekologie/Vegetationszonen
IMPORTER_SKIP_UINFO_VEGETATION=false

#####################################################################

MIN_MEMORY="8192m"

######################### Run Importer ##############################
INFO_GEW=$1

OPTIONAL_LIBS="${DIR}"/../opt
if [ -d "$OPTIONAL_LIBS" ]; then
    export PATH="$OPTIONAL_LIBS/bin:$PATH"
    export LD_LIBRARY_PATH="$OPTIONAL_LIBS/lib:$LD_LIBRARY_PATH"
    export LD_LIBRARY_PATH="$OPTIONAL_LIBS/lib64:$LD_LIBRARY_PATH"
fi

# Default encoding. Change here if necessary
export LC_ALL=de_DE@euro

exec java -jar \
    -Xmx$MIN_MEMORY \
    -server \
    -Dlog4j.configuration=file://`readlink -f $LOG4J_CONFIG` \
    -Dflys.backend.importer.infogew.file=$INFO_GEW \
    -Dflys.backend.importer.annotation.types=$IMPORTER_ANNOTATION_TYPES \
    -Dflys.backend.importer.dry.run=$IMPORTER_DRY_RUN \
    -Dflys.backend.importer.skip.default=$IMPORTER_SKIP_DEFAULT \
    -Dflys.backend.importer.skip.sinfo.selected_additional=$IMPORTER_SKIP_SINFO_SELECTED_ADDITIONAL \
    -Dflys.backend.importer.skip.sinfo.infrastructure=$IMPORTER_SKIP_SINFO_INFRASTRUCTURE \
    -Dflys.backend.importer.skip.sinfo.bed_mobility=$IMPORTER_SKIP_SINFO_BED_MOBILITY \
    -Dflys.backend.importer.skip.sinfo.channel=$IMPORTER_SKIP_SINFO_CHANNEL \
    -Dflys.backend.importer.skip.sinfo.collision=$IMPORTER_SKIP_SINFO_COLLISION \
    -Dflys.backend.importer.skip.sinfo.daily_discharge=$IMPORTER_SKIP_SINFO_DAILY_DISCHARGE \
    -Dflys.backend.importer.skip.sinfo.tkh=$IMPORTER_SKIP_SINFO_TKH \
    -Dflys.backend.importer.skip.sinfo.flow_depth=$IMPORTER_SKIP_SINFO_FLOW_DEPTH \
    -Dflys.backend.importer.skip.sinfo.depth_evolution=$IMPORTER_SKIP_SINFO_DEPTH_EVOLUTION \
    -Dflys.backend.importer.skip.uinfo.iota=$IMPORTER_SKIP_UINFO_IOTA \
    -Dflys.backend.importer.skip.uinfo.vegetation=$IMPORTER_SKIP_UINFO_VEGETATION \
    -Dflys.backend.user=$BACKEND_USER \
    -Dflys.backend.password=$BACKEND_PASS \
    -Dflys.backend.url=$BACKEND_URL \
    -Dflys.backend.driver=$BACKEND_DB_DRIVER \
    -Dflys.backend.dialect=$BACKEND_DB_DIALECT \
     $JAR
